/*
 * VNPForth - Compiled native Forth for IA32 Linux systems
 * Copyright (C) 2001  Simon Baldwin (simonb@caldera.com)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 *
 * forthlib.h - Header and definitions for the VNPForth runtime library.
 *
 */

#ifndef _FORTHLIB_H
#define	_FORTHLIB_H

/* Enable use with C++. */
#if defined(__cplusplus)
extern "C" {
#endif /* __cplusplus */

/* _dstack: Forth data stack, 4096 cells */
#ifndef _NO_VNPFORTH__dstack
extern int	_dstack[4096];
#endif

/* _dsindx: Forth data stack current index */
#ifndef _NO_VNPFORTH__dsindx
extern int	_dsindx;
#endif

/* DROP: (w --) Drop an item from the data stack */
#ifndef _NO_VNPFORTH_DROP
extern void	DROP (void);
#endif

/* SWAP: (w1 w2 -- w2 w1) Swap the top two items of the stack */
#ifndef _NO_VNPFORTH_SWAP
extern void	SWAP (void);
#endif

/* DEPTH: (-- n) Return the depth of the stack */
#ifndef _NO_VNPFORTH_DEPTH
extern void	DEPTH (void);
#endif

/* SP0: ( -- a) Return the address of the data stack base */
#ifndef _NO_VNPFORTH_SP0
extern void	SP0 (void);
#endif

/* SP@: (-- a) Return the effective address of the data stack pointer */
#ifndef _NO_VNPFORTH_SP_Fetch
extern void	SP_Fetch (void);
#endif

/* DUP: (w -- w w) Duplicate the top item of the stack */
#ifndef _NO_VNPFORTH_DUP
extern void	DUP (void);
#endif

/* OVER: (w1 w2 -- w1 w2 w1) Duplicate w1 onto the top of the stack */
#ifndef _NO_VNPFORTH_OVER
extern void	OVER (void);
#endif

/* ?DUP: (w -- w w | 0) Duplicate w if nonzero */
#ifndef _NO_VNPFORTH_QuestionDUP
extern void	QuestionDUP (void);
#endif

/* NIP: (w1 w2 -- w2) Remove the item under the top of the stack */
#ifndef _NO_VNPFORTH_NIP
extern void	NIP (void);
#endif

/* ROT: (w1 w2 w3 -- w2 w3 w1) Rotate the top three stacked items */
#ifndef _NO_VNPFORTH_ROT
extern void	ROT (void);
#endif

/* TUCK: (w1 w2 -- w2 w1 w2) Tuck the top item under its underling */
#ifndef _NO_VNPFORTH_TUCK
extern void	TUCK (void);
#endif

/* PICK: (wn wn-1 ... w0 x -- wn wn-1 ... w0 wx) Pick item x from the stack */
#ifndef _NO_VNPFORTH_PICK
extern void	PICK (void);
#endif

/* ROLL: (wn wn-1 ... w0 n -- wn-1 ... w0 wn) Roll top n stack items */
#ifndef _NO_VNPFORTH_ROLL
extern void	ROLL (void);
#endif

/* 2DROP: (w1 w2 --) Drop the top two items */
#ifndef _NO_VNPFORTH_z2DROP
extern void	z2DROP (void);
#endif

/* 2DUP: (w1 w2 -- w1 w2 w1 w2) Duplicate the top two items */
#ifndef _NO_VNPFORTH_z2DUP
extern void	z2DUP (void);
#endif

/* 2OVER: (w1 w2 w3 w4 -- w1 w2 w3 w4 w1 w2) Copy w1 w2 over w3 w4 */
#ifndef _NO_VNPFORTH_z2OVER
extern void	z2OVER (void);
#endif

/* 2SWAP: (w1 w2 w3 w4 -- w3 w4 w1 w2) Swap the top two pairs of items */
#ifndef _NO_VNPFORTH_z2SWAP
extern void	z2SWAP (void);
#endif

/* _rstack: Forth return stack, 4096 cells */
#ifndef _NO_VNPFORTH__rstack
extern int	_rstack[4096];
#endif

/* _rsindx: Forth return stack current index */
#ifndef _NO_VNPFORTH__rsindx
extern int	_rsindx;
#endif

/* R@: (-- w) Return the value on the current return stack top */
#ifndef _NO_VNPFORTH_R_Fetch
extern void	R_Fetch (void);
#endif

/* >R: (w --) (R: -- w) Transfer w from the data to the return stack */
#ifndef _NO_VNPFORTH_GreaterR
extern void	GreaterR (void);
#endif

/* R>: (-- w) (R: w --) Transfer w from the return to the data stack */
#ifndef _NO_VNPFORTH_R_Greater
extern void	R_Greater (void);
#endif

/* RDEPTH: (-- n) Return the current depth of the return stack */
#ifndef _NO_VNPFORTH_RDEPTH
extern void	RDEPTH (void);
#endif

/* RP0: ( -- n) Return the return stack base pointer */
#ifndef _NO_VNPFORTH_RP0
extern void	RP0 (void);
#endif

/* RP@: (-- n) Return the return stack effective current pointer */
#ifndef _NO_VNPFORTH_RP_Fetch
extern void	RP_Fetch (void);
#endif

/* 2>R: (w1 w2 --) (R: -- w1 w2) Transfer a pair of values from data */
#ifndef _NO_VNPFORTH_z2_GreaterR
extern void	z2_GreaterR (void);
#endif

/* 2R>: (-- w1 w2) (R: w1 w2 --) Transfer a pair of values to data */
#ifndef _NO_VNPFORTH_z2R_Greater
extern void	z2R_Greater (void);
#endif

/* 2R@: (-- w1 w2) Copy the top two return stack values to data */
#ifndef _NO_VNPFORTH_z2R_Fetch
extern void	z2R_Fetch (void);
#endif

/* EXECUTE: (xt --) Call function at address xt */
#ifndef _NO_VNPFORTH_EXECUTE
extern void	EXECUTE (void);
#endif

/* !: (w a --) Store w at address a */
#ifndef _NO_VNPFORTH_Store
extern void	Store (void);
#endif

/* @: (a -- w) Fetch w from address a */
#ifndef _NO_VNPFORTH_Fetch
extern void	Fetch (void);
#endif

/* C!: (c b --) Store character c at address b */
#ifndef _NO_VNPFORTH_C_Store
extern void	C_Store (void);
#endif

/* C@: (b -- c) Fetch character c from address b */
#ifndef _NO_VNPFORTH_C_Fetch
extern void	C_Fetch (void);
#endif

/* +!: (n a --) Increment address a, and store n at new address */
#ifndef _NO_VNPFORTH_Plus_Store
extern void	Plus_Store (void);
#endif

/* 2!: (w1 w2 a --) Store w1 w2 in consecutive words at address a */
#ifndef _NO_VNPFORTH_z2_Store
extern void	z2_Store (void);
#endif

/* 2@: (a -- w1 w2) Fetch w1 w2 from consecutive words at address a */
#ifndef _NO_VNPFORTH_z2_Fetch
extern void	z2_Fetch (void);
#endif

/* FILL: (a u ch --) Fill addresses a to a+u with character ch */
#ifndef _NO_VNPFORTH_FILL
extern void	FILL (void);
#endif

/* MOVE: (a1 a2 u --) Copy u characters from a1 to a2 */
#ifndef _NO_VNPFORTH_MOVE
extern void	MOVE (void);
#endif

/* ERASE: (a u --) Fill u characters, from a to a+u, with zeroes */
#ifndef _NO_VNPFORTH_ERASE
extern void	ERASE (void);
#endif

/* ALIGNED: (a -- a) Return first aligned address greater than or equal to a */
#ifndef _NO_VNPFORTH_ALIGNED
extern void	ALIGNED (void);
#endif

/* AND: (w1 w2 -- w) Return logical AND of w1 w2 */
#ifndef _NO_VNPFORTH_AND
extern void	AND (void);
#endif

/* OR: (w1 w2 -- w) Return the logical OR of w1 w2 */
#ifndef _NO_VNPFORTH_OR
extern void	OR (void);
#endif

/* XOR: (w1 w2 -- w) Return the logical XOR of w1 w2 */
#ifndef _NO_VNPFORTH_XOR
extern void	XOR (void);
#endif

/* LSHIFT: (w u -- w) Left shift w by u bits */
#ifndef _NO_VNPFORTH_LSHIFT
extern void	LSHIFT (void);
#endif

/* RSHIFT: (w u -- w) Right shift w by u bits */
#ifndef _NO_VNPFORTH_RSHIFT
extern void	RSHIFT (void);
#endif

/* INVERT: (w -- w) Invert each bit in w */
#ifndef _NO_VNPFORTH_INVERT
extern void	INVERT (void);
#endif

/* FALSE: --  0 */
#ifndef _NO_VNPFORTH_FALSE
extern void	FALSE (void);
#endif

/* TRUE: -- -1 */
#ifndef _NO_VNPFORTH_TRUE
extern void	TRUE (void);
#endif

/* 1+: (n -- n) Increment n */
#ifndef _NO_VNPFORTH_z1_Plus
extern void	z1_Plus (void);
#endif

/* 1-: (n -- n) Decrement n */
#ifndef _NO_VNPFORTH_z1_Minus
extern void	z1_Minus (void);
#endif

/* UM+: (u1 u2 -- ur cy) Add u1 to u2 giving ur and cy */
#ifndef _NO_VNPFORTH_UM_Plus
extern void	UM_Plus (void);
#endif

/* UM*: (u1 u2 -- ur cy) Multiply u1 by u2 giving double result */
#ifndef _NO_VNPFORTH_UM_Star
extern void	UM_Star (void);
#endif

/* UM/MOD: (udl udh un -- ur uq) Divide udh:udl by un, leaving ur and uq */
#ifndef _NO_VNPFORTH_UM_SlashMOD
extern void	UM_SlashMOD (void);
#endif

/* SM/REM: (dl dh n -- r q) Divide dh:dl by n, leaving r and q */
#ifndef _NO_VNPFORTH_SM_SlashREM
extern void	SM_SlashREM (void);
#endif

/* FM/MOD: (dl dh n -- r q) Floored division of dh:dl by n, leaving r and q */
#ifndef _NO_VNPFORTH_FM_SlashMOD
extern void	FM_SlashMOD (void);
#endif

/* +: (u1 u2 -- ur) Add u1 to u2, ignoring carry */
#ifndef _NO_VNPFORTH_Plus
extern void	Plus (void);
#endif

/* NEGATE: (n -- -n) Change sign of n */
#ifndef _NO_VNPFORTH_NEGATE
extern void	NEGATE (void);
#endif

/* DNEGATE: (d -- -d) Change sign of d */
#ifndef _NO_VNPFORTH_DNEGATE
extern void	DNEGATE (void);
#endif

/* -: (w1 w2 -- wr) Subtract w2 from w1, giving wr */
#ifndef _NO_VNPFORTH_Minus
extern void	Minus (void);
#endif

/* ABS: (n -- +n) Obtain absolute value of n */
#ifndef _NO_VNPFORTH_ABS
extern void	ABS (void);
#endif

/* M*: (n1 n2 -- d) Multiply n1 by n2, giving d */
#ifndef _NO_VNPFORTH_M_Star
extern void	M_Star (void);
#endif

/* *: (n1 n2 -- n) Multiply n1 by n2, ignoring overflow */
#ifndef _NO_VNPFORTH_Star
extern void	Star (void);
#endif

/* M/MOD: (dl dh n -- r q) Division of dh:dl by n, leaving r and q */
#ifndef _NO_VNPFORTH_M_SlashMOD
extern void	M_SlashMOD (void);
#endif

/* /MOD: (n1 n2 -- r q) Divide n1 by n2, return remainder and quotient */
#ifndef _NO_VNPFORTH_SlashMOD
extern void	SlashMOD (void);
#endif

/* MOD: (n1 n2 -- n) Return the remainder of dividing n1 by n2 */
#ifndef _NO_VNPFORTH_MOD
extern void	MOD (void);
#endif

/* /: (n1 n2 -- n) Divide n1 by n2 */
#ifndef _NO_VNPFORTH_Slash
extern void	Slash (void);
#endif

/* * /MOD: (n1 n2 n3 -- n4 n5) Return remainder and quotient of n1 * n2 / n3 */
#ifndef _NO_VNPFORTH_Star_SlashMOD
extern void	Star_SlashMOD (void);
#endif

/* * /: (n1 n2 n3 -- n) Return n1 * n2 / n3 */
#ifndef _NO_VNPFORTH_Star_Slash
extern void	Star_Slash (void);
#endif

/* S>D: (n -- d) Convert signed n to double d */
#ifndef _NO_VNPFORTH_S_GreaterD
extern void	S_GreaterD (void);
#endif

/* 2*: (n -- n) Double n */
#ifndef _NO_VNPFORTH_z2_Star
extern void	z2_Star (void);
#endif

/* 2/: (n -- n) Halve n, leaving MSB unchanged */
#ifndef _NO_VNPFORTH_z2_Slash
extern void	z2_Slash (void);
#endif

/* 0<: (n -- t) Return nonzero if n < 0 */
#ifndef _NO_VNPFORTH_z0_Less
extern void	z0_Less (void);
#endif

/* 0=: (w -- t) Return nonzero if w = 0 */
#ifndef _NO_VNPFORTH_z0_Equals
extern void	z0_Equals (void);
#endif

/* =: (w1 w2 -- t) Return nonzero if w1 = w2 */
#ifndef _NO_VNPFORTH_Equals
extern void	Equals (void);
#endif

/* U<: (u1 u2 -- t) Return nonzero if u1 < u2 */
#ifndef _NO_VNPFORTH_U_Less
extern void	U_Less (void);
#endif

/* <: (n1 n2 -- t) Return nonzero if n1 < n2 */
#ifndef _NO_VNPFORTH_Less
extern void	Less (void);
#endif

/* MAX: (n1 n2 -- n) Return the larger of n1 n2 */
#ifndef _NO_VNPFORTH_MAX
extern void	MAX (void);
#endif

/* MIN: (n1 n2 -- n) Return the smaller of n1 n2 */
#ifndef _NO_VNPFORTH_MIN
extern void	MIN (void);
#endif

/* WITHIN: (u ul uh -- t) Return true if u lies between ul and uh */
#ifndef _NO_VNPFORTH_WITHIN
extern void	WITHIN (void);
#endif

/* >: (n1 n2 -- t) Test if n1 > n2 */
#ifndef _NO_VNPFORTH_Greater
extern void	Greater (void);
#endif

/* 0<>: (n -- t) Test if n != 0 */
#ifndef _NO_VNPFORTH_z0_Less_Greater
extern void	z0_Less_Greater (void);
#endif

/* 0>: (n -- t) Test if n > 0 */
#ifndef _NO_VNPFORTH_z0_Greater
extern void	z0_Greater (void);
#endif

/* <>: (n1 n2 -- t) Test if n1 != n2 */
#ifndef _NO_VNPFORTH_Less_Greater
extern void	Less_Greater (void);
#endif

/* U>: (u1 u2 -- t) Test if u1 > u2 */
#ifndef _NO_VNPFORTH_U_Greater
extern void	U_Greater (void);
#endif

/* EMIT: (c --) Send c to stdout */
#ifndef _NO_VNPFORTH_EMIT
extern void	EMIT (void);
#endif

/* KEY: (-- c) Read c from stdin */
#ifndef _NO_VNPFORTH_KEY
extern void	KEY (void);
#endif

/* TYPE: (a u --) Print string of length u at a */
#ifndef _NO_VNPFORTH_TYPE
extern void	TYPE (void);
#endif

/* BL: (-- c) ASCII space character */
#ifndef _NO_VNPFORTH_BL
extern void	BL (void);
#endif

/* SPACE: (--) Write one space to stdout */
#ifndef _NO_VNPFORTH_SPACE
extern void	SPACE (void);
#endif

/* SPACES: (n --) Write n spaces to stdout */
#ifndef _NO_VNPFORTH_SPACES
extern void	SPACES (void);
#endif

/* CR: (--) Write carriage return to stdout */
#ifndef _NO_VNPFORTH_CR
extern void	CR (void);
#endif

/* ACCEPT: (a n -- n) Read in up to n characters to a, return count */
#ifndef _NO_VNPFORTH_ACCEPT
extern void	ACCEPT (void);
#endif

/* COUNT: (a -- a+1 n) Convert counted string into address and count */
#ifndef _NO_VNPFORTH_COUNT
extern void	COUNT (void);
#endif

/* PAD: Conversion output buffer, 84 chars */
#ifndef _NO_VNPFORTH_PAD
extern char	PAD[84];
#endif

/* HLD: Hold pointer into buffer */
#ifndef _NO_VNPFORTH_HLD
extern int	HLD;
#endif

/* vBASE: Current I/O numeric base */
#ifndef _NO_VNPFORTH_vBASE
extern int	vBASE;
#endif

/* BASE: (-- a) Initialize BASE to ten if not yet set, return address */
#ifndef _NO_VNPFORTH_BASE
extern void	BASE (void);
#endif

/* <#: (--) Set HLD to the end of PAD */
#ifndef _NO_VNPFORTH_Less_Hash
extern void	Less_Hash (void);
#endif

/* HOLD: (c --) Decrement HLD, and place c in PAD buffer */
#ifndef _NO_VNPFORTH_HOLD
extern void	HOLD (void);
#endif

/* #: (ud -- ud) Place least digit of ud in PAD, return ud / BASE */
#ifndef _NO_VNPFORTH_Hash
extern void	Hash (void);
#endif

/* #S: (ud -- 0 0) Place all digits of u in PAD, return 0 0 */
#ifndef _NO_VNPFORTH_HashS
extern void	HashS (void);
#endif

/* SIGN: (n --) Append '-' to PAD if n is negative */
#ifndef _NO_VNPFORTH_SIGN
extern void	SIGN (void);
#endif

/* #>: (w w -- b u) Return PAD as a string and char count */
#ifndef _NO_VNPFORTH_Hash_Greater
extern void	Hash_Greater (void);
#endif

/* HEX: (--) Set base 16 */
#ifndef _NO_VNPFORTH_HEX
extern void	HEX (void);
#endif

/* DECIMAL: (--) Set base 10 */
#ifndef _NO_VNPFORTH_DECIMAL
extern void	DECIMAL (void);
#endif

/* OCTAL: (--) Set base 8 */
#ifndef _NO_VNPFORTH_OCTAL
extern void	OCTAL (void);
#endif

/* U.R: (u n --) print u unsigned right-justified to width n, in base BASE */
#ifndef _NO_VNPFORTH_U_DotR
extern void	U_DotR (void);
#endif

/* .R: (w n --) Print w, signed if BASE = 10, otherwise unsigned, width n */
#ifndef _NO_VNPFORTH_DotR
extern void	DotR (void);
#endif

/* U.: (u --) Print u unsigned, in base BASE */
#ifndef _NO_VNPFORTH_U_Dot
extern void	U_Dot (void);
#endif

/* .: (w --) Print w, signed if BASE = 10, otherwise unsigned */
#ifndef _NO_VNPFORTH_Dot
extern void	Dot (void);
#endif

/* .S: (w1 ... wn --) Print the contents of the data stack */
#ifndef _NO_VNPFORTH_DotS
extern void	DotS (void);
#endif

/* >NUMBER: (ud1 c-addr1 u1 -- ud2 c-addr2 u2) Convert string to number */
#ifndef _NO_VNPFORTH_GreaterNUMBER
extern void	GreaterNUMBER (void);
#endif

/* =CELL: (-- n) Size of a cell */
#ifndef _NO_VNPFORTH_EqualsCELL
extern void	EqualsCELL (void);
#endif

/* =CHAR: (-- n) Size of a char */
#ifndef _NO_VNPFORTH_EqualsCHAR
extern void	EqualsCHAR (void);
#endif

/* CELLS: (n -- a) Convert n to cell offset */
#ifndef _NO_VNPFORTH_CELLS
extern void	CELLS (void);
#endif

/* CHARS: (n -- a) Convert n to char offset */
#ifndef _NO_VNPFORTH_CHARS
extern void	CHARS (void);
#endif

/* CELL+: (a -- a) Advance a by 1 cell */
#ifndef _NO_VNPFORTH_CELL_Plus
extern void	CELL_Plus (void);
#endif

/* CHAR+: (a -- a) Advance a by 1 char */
#ifndef _NO_VNPFORTH_CHAR_Plus
extern void	CHAR_Plus (void);
#endif

/* >CHAR: (c -- c) Test if c is out of ASCII range */
#ifndef _NO_VNPFORTH_GreaterCHAR
extern void	GreaterCHAR (void);
#endif

/* I: (-- n) Inner DO loop index value */
#ifndef _NO_VNPFORTH_I
extern void	I (void);
#endif

/* J: (-- n) Next DO loop index value */
#ifndef _NO_VNPFORTH_J
extern void	J (void);
#endif

/* K: (-- n) Next DO loop index value */
#ifndef _NO_VNPFORTH_K
extern void	K (void);
#endif

/* UNLOOP: (R: w w --) Discard DO loop return stack values for EXIT */
#ifndef _NO_VNPFORTH_UNLOOP
extern void	UNLOOP (void);
#endif

/* vSTATE: Underlying variable for STATE */
#ifndef _NO_VNPFORTH_vSTATE
extern int	vSTATE;
#endif

/* STATE: (-- a-addr) Return address of STATE */
#ifndef _NO_VNPFORTH_STATE
extern void	STATE (void);
#endif

/* [: (--) Null definition for compatibility */
#ifndef _NO_VNPFORTH_Leftbracket
extern void	Leftbracket (void);
#endif

/* ]: (--) Null definition for compatibility */
#ifndef _NO_VNPFORTH_Rightbracket
extern void	Rightbracket (void);
#endif

/* LITERAL: (--) Null definition for compatibility */
#ifndef _NO_VNPFORTH_LITERAL
extern void	LITERAL (void);
#endif

/* IMMEDIATE: (--) Null definition for compatibility */
#ifndef _NO_VNPFORTH_IMMEDIATE
extern void	IMMEDIATE (void);
#endif

/* bHERE: Underlying buf for HERE, 1024 chars */
#ifndef _NO_VNPFORTH_bHERE
extern char	bHERE[1024];
#endif

/* vHERE: Underlying variable for HERE */
#ifndef _NO_VNPFORTH_vHERE
extern int	vHERE;
#endif

/* HERE: (-- addr) Return address of compatibility region */
#ifndef _NO_VNPFORTH_HERE
extern void	HERE (void);
#endif

/* ,: (x --) Store x in compatibility region */
#ifndef _NO_VNPFORTH_Comma
extern void	Comma (void);
#endif

/* C,: (c --) Store c in compatibility region */
#ifndef _NO_VNPFORTH_C_Comma
extern void	C_Comma (void);
#endif

/* ALIGN: (--) Align compatibilty data space pointer */
#ifndef _NO_VNPFORTH_ALIGN
extern void	ALIGN (void);
#endif

/* ?str=: (c-addr1 u1 c-addr2 u2 -- f) Compare string c-addr1 to c-addr2 */
#ifndef _NO_VNPFORTH_Questionstr_Equals
extern void	Questionstr_Equals (void);
#endif

/* ENVIRONMENT?: (c-addr u -- false | i|n|f|d|u true) Query the environment */
#ifndef _NO_VNPFORTH_ENVIRONMENT_Question
extern void	ENVIRONMENT_Question (void);
#endif

/* _fsindx: Forth FP stack current index */
#ifndef _NO_VNPFORTH__fsindx
extern int	_fsindx;
#endif

/* _fstemp: Temporary FP variable */
#ifndef _NO_VNPFORTH__fstemp
extern int	_fstemp;
#endif

/* _fsinit: FPU initialization flag */
#ifndef _NO_VNPFORTH__fsinit
extern int	_fsinit;
#endif

/* =FLOAT: (-- n) Size of a float */
#ifndef _NO_VNPFORTH_EqualsFLOAT
extern void	EqualsFLOAT (void);
#endif

/* FLOATS: (n -- a) Convert n to float offset */
#ifndef _NO_VNPFORTH_FLOATS
extern void	FLOATS (void);
#endif

/* FLOAT+: (a -- a) Advance a by one float */
#ifndef _NO_VNPFORTH_FLOAT_Plus
extern void	FLOAT_Plus (void);
#endif

/* >F: (w --) (F: -- r) Transfer w from the data to the FP stack */
#ifndef _NO_VNPFORTH_GreaterF
extern void	GreaterF (void);
#endif

/* F>: (-- w) (F: r --) Transfer r from the FP to the data stack */
#ifndef _NO_VNPFORTH_F_Greater
extern void	F_Greater (void);
#endif

/* FDEPTH: (-- n) Return the depth of the FP stack */
#ifndef _NO_VNPFORTH_FDEPTH
extern void	FDEPTH (void);
#endif

/* FDROP: (F: r --) Drop an item from the FP stack */
#ifndef _NO_VNPFORTH_FDROP
extern void	FDROP (void);
#endif

/* F!: (f-addr --) (F: r --) Store r at address f-addr */
#ifndef _NO_VNPFORTH_F_Store
extern void	F_Store (void);
#endif

/* F@: (f-addr --) (F: -- r) Fetch r from address a */
#ifndef _NO_VNPFORTH_F_Fetch
extern void	F_Fetch (void);
#endif

/* FSWAP: (F: r1 r2 -- r2 r1) Swap the top two items of the FP stack */
#ifndef _NO_VNPFORTH_FSWAP
extern void	FSWAP (void);
#endif

/* FDUP: (F: r -- r r) Duplicate the top item of the FP stack */
#ifndef _NO_VNPFORTH_FDUP
extern void	FDUP (void);
#endif

/* FOVER: (F: r1 r2 -- r1 r2 r1) Duplicate r1 onto the top of the FP stack */
#ifndef _NO_VNPFORTH_FOVER
extern void	FOVER (void);
#endif

/* FROT: (F: r1 r2 r3 -- r2 r3 r1) Rotate the top three FP stacked items */
#ifndef _NO_VNPFORTH_FROT
extern void	FROT (void);
#endif

/* F+: (F: r1 r2 -- r) Add r1 to r2 */
#ifndef _NO_VNPFORTH_F_Plus
extern void	F_Plus (void);
#endif

/* F-: (F: r1 r2 -- r) Subtract r2 from r1 */
#ifndef _NO_VNPFORTH_F_Minus
extern void	F_Minus (void);
#endif

/* F*: (F: r1 r2 -- r) Multiply r1 by r2 */
#ifndef _NO_VNPFORTH_F_Star
extern void	F_Star (void);
#endif

/* F/: (F: r1 r2 -- r) Divide r1 by r2 */
#ifndef _NO_VNPFORTH_F_Slash
extern void	F_Slash (void);
#endif

/* F0<: (-- t) (F: r --) Return true if r is less than 0.0 */
#ifndef _NO_VNPFORTH_F0_Less
extern void	F0_Less (void);
#endif

/* F0=: (-- t) (F: r --) Return true if r is equal to 0.0 */
#ifndef _NO_VNPFORTH_F0_Equals
extern void	F0_Equals (void);
#endif

/* F<: (-- t) (F: r1 r2 --) Return true if r1 is less than r2 */
#ifndef _NO_VNPFORTH_F_Less
extern void	F_Less (void);
#endif

/* FABS: (F: -r|+r -- +r) Negate r if r is negative */
#ifndef _NO_VNPFORTH_FABS
extern void	FABS (void);
#endif

/* FNEGATE: (F: r -- -r) Negate r */
#ifndef _NO_VNPFORTH_FNEGATE
extern void	FNEGATE (void);
#endif

/* FMAX: (F: r1 r2 -- r) Return the larger of r1 r2 */
#ifndef _NO_VNPFORTH_FMAX
extern void	FMAX (void);
#endif

/* FMIN: (F: r1 r2 -- r) Return the smaller of r1 r2 */
#ifndef _NO_VNPFORTH_FMIN
extern void	FMIN (void);
#endif

/* FSQRT: (F: r -- r^0.5) Calculate the square root of r */
#ifndef _NO_VNPFORTH_FSQRT
extern void	FSQRT (void);
#endif

/* FSIN: (F: r -- r) Calculate the sin of r */
#ifndef _NO_VNPFORTH_FSIN
extern void	FSIN (void);
#endif

/* FCOS: (F: r -- r) Calculate the cos of r */
#ifndef _NO_VNPFORTH_FCOS
extern void	FCOS (void);
#endif

/* FSINCOS: (F: r -- rs rc) Calculate the cos [rs] and sin [rc] of r */
#ifndef _NO_VNPFORTH_FSINCOS
extern void	FSINCOS (void);
#endif

/* FTAN: (F: r -- r) Calculate the tan of r */
#ifndef _NO_VNPFORTH_FTAN
extern void	FTAN (void);
#endif

/* FROUND: (F: r -- r) Round r to an integral value */
#ifndef _NO_VNPFORTH_FROUND
extern void	FROUND (void);
#endif

/* STRLEN: (c-addr -- c-addr u) Return addr, length of null-terminated string */
#ifndef _NO_VNPFORTH_STRLEN
extern void	STRLEN (void);
#endif

/* ?envstr=: (c-addr1 u1 env-addr -- f) Compare environ LHS string */
#ifndef _NO_VNPFORTH_Questionenvstr_Equals
extern void	Questionenvstr_Equals (void);
#endif

/* GETENV: (env-addr c-addr u -- false | c-addr u true) Get process env value */
#ifndef _NO_VNPFORTH_GETENV
extern void	GETENV (void);
#endif

/* CEXECUTE: (a1 ... aN N xt -- status) Call C func xt with N arguments */
#ifndef _NO_VNPFORTH_CEXECUTE
extern void	CEXECUTE (void);
#endif

/* fdpush: (-- w) Transfer an argument from C to the Forth stack */
#ifndef _NO_VNPFORTH_fdpush
extern void	fdpush (int);
#endif

/* fdpop: (w --) Leave Forth top of stack in eax for C */
#ifndef _NO_VNPFORTH_fdpop
extern int	fdpop (void);
#endif

/* _atexit: System _atexit handler address */
#ifndef _NO_VNPFORTH__atexit
extern int	_atexit;
#endif

/* _start: (--) Forth program entry point, invoked by Linux exec */
#ifndef _NO_VNPFORTH__start
extern void	_start (void);
#endif

/* _SYSCALL: (a1 ... aN X N -- status) Call syscall X with N arguments */
#ifndef _NO_VNPFORTH__SYSCALL
extern void	_SYSCALL (void);
#endif

/* vERRNO: Underlying variable for ERRNO */
#ifndef _NO_VNPFORTH_vERRNO
extern int	vERRNO;
#endif

/* _POST_SYSCALL: (r -- r | -1) Returns r, or sets ERRNO and returns -1 */
#ifndef _NO_VNPFORTH__POST_SYSCALL
extern void	_POST_SYSCALL (void);
#endif

/* ERRNO: (-- a) Returns the address of the ERRNO variable */
#ifndef _NO_VNPFORTH_ERRNO
extern void	ERRNO (void);
#endif

/* _EXIT: n1     -- r */
#ifndef _NO_VNPFORTH__EXIT
extern void	_EXIT (void);
#endif

/* _FORK: -- r */
#ifndef _NO_VNPFORTH__FORK
extern void	_FORK (void);
#endif

/* _READ: n1...3 -- r */
#ifndef _NO_VNPFORTH__READ
extern void	_READ (void);
#endif

/* _WRITE: n1...3 -- r */
#ifndef _NO_VNPFORTH__WRITE
extern void	_WRITE (void);
#endif

/* _OPEN: n1...3 -- r */
#ifndef _NO_VNPFORTH__OPEN
extern void	_OPEN (void);
#endif

/* _CLOSE: n1     -- r */
#ifndef _NO_VNPFORTH__CLOSE
extern void	_CLOSE (void);
#endif

/* _WAITPID: n1...3 -- r */
#ifndef _NO_VNPFORTH__WAITPID
extern void	_WAITPID (void);
#endif

/* _CREAT: n1...2 -- r */
#ifndef _NO_VNPFORTH__CREAT
extern void	_CREAT (void);
#endif

/* _LINK: n1...2 -- r */
#ifndef _NO_VNPFORTH__LINK
extern void	_LINK (void);
#endif

/* _UNLINK: n1     -- r */
#ifndef _NO_VNPFORTH__UNLINK
extern void	_UNLINK (void);
#endif

/* _EXECVE: n1...3 -- r */
#ifndef _NO_VNPFORTH__EXECVE
extern void	_EXECVE (void);
#endif

/* _CHDIR: n1     -- r */
#ifndef _NO_VNPFORTH__CHDIR
extern void	_CHDIR (void);
#endif

/* _TIME: n1     -- r */
#ifndef _NO_VNPFORTH__TIME
extern void	_TIME (void);
#endif

/* _MKNOD: n1...3 -- r */
#ifndef _NO_VNPFORTH__MKNOD
extern void	_MKNOD (void);
#endif

/* _CHMOD: n1...2 -- r */
#ifndef _NO_VNPFORTH__CHMOD
extern void	_CHMOD (void);
#endif

/* _LCHOWN16: n1...3 -- r */
#ifndef _NO_VNPFORTH__LCHOWN16
extern void	_LCHOWN16 (void);
#endif

/* _LSEEK: n1...3 -- r */
#ifndef _NO_VNPFORTH__LSEEK
extern void	_LSEEK (void);
#endif

/* _GETPID: -- r */
#ifndef _NO_VNPFORTH__GETPID
extern void	_GETPID (void);
#endif

/* _MOUNT: n1...5 -- r */
#ifndef _NO_VNPFORTH__MOUNT
extern void	_MOUNT (void);
#endif

/* _SETUID16: n1     -- r */
#ifndef _NO_VNPFORTH__SETUID16
extern void	_SETUID16 (void);
#endif

/* _GETUID16: -- r */
#ifndef _NO_VNPFORTH__GETUID16
extern void	_GETUID16 (void);
#endif

/* _STIME: n1     -- r */
#ifndef _NO_VNPFORTH__STIME
extern void	_STIME (void);
#endif

/* _ALARM: n1     -- r */
#ifndef _NO_VNPFORTH__ALARM
extern void	_ALARM (void);
#endif

/* _PAUSE: -- r */
#ifndef _NO_VNPFORTH__PAUSE
extern void	_PAUSE (void);
#endif

/* _UTIME: n1...2 -- r */
#ifndef _NO_VNPFORTH__UTIME
extern void	_UTIME (void);
#endif

/* _ACCESS: n1...2 -- r */
#ifndef _NO_VNPFORTH__ACCESS
extern void	_ACCESS (void);
#endif

/* _NICE: n1     -- r */
#ifndef _NO_VNPFORTH__NICE
extern void	_NICE (void);
#endif

/* _KILL: n1...2 -- r */
#ifndef _NO_VNPFORTH__KILL
extern void	_KILL (void);
#endif

/* _RENAME: n1...2 -- r */
#ifndef _NO_VNPFORTH__RENAME
extern void	_RENAME (void);
#endif

/* _MKDIR: n1...2 -- r */
#ifndef _NO_VNPFORTH__MKDIR
extern void	_MKDIR (void);
#endif

/* _RMDIR: n1     -- r */
#ifndef _NO_VNPFORTH__RMDIR
extern void	_RMDIR (void);
#endif

/* _DUP: n1     -- r */
#ifndef _NO_VNPFORTH__DUP
extern void	_DUP (void);
#endif

/* _PIPE: n1     -- r */
#ifndef _NO_VNPFORTH__PIPE
extern void	_PIPE (void);
#endif

/* _TIMES: n1     -- r */
#ifndef _NO_VNPFORTH__TIMES
extern void	_TIMES (void);
#endif

/* _BRK: n1     -- r */
#ifndef _NO_VNPFORTH__BRK
extern void	_BRK (void);
#endif

/* _SETGID16: n1     -- r */
#ifndef _NO_VNPFORTH__SETGID16
extern void	_SETGID16 (void);
#endif

/* _GETGID16: -- r */
#ifndef _NO_VNPFORTH__GETGID16
extern void	_GETGID16 (void);
#endif

/* _SIGNAL: n1...2 -- r */
#ifndef _NO_VNPFORTH__SIGNAL
extern void	_SIGNAL (void);
#endif

/* _GETEUID16: -- r */
#ifndef _NO_VNPFORTH__GETEUID16
extern void	_GETEUID16 (void);
#endif

/* _GETEGID16: -- r */
#ifndef _NO_VNPFORTH__GETEGID16
extern void	_GETEGID16 (void);
#endif

/* _IOCTL: n1...3 -- r */
#ifndef _NO_VNPFORTH__IOCTL
extern void	_IOCTL (void);
#endif

/* _FCNTL: n1...3 -- r */
#ifndef _NO_VNPFORTH__FCNTL
extern void	_FCNTL (void);
#endif

/* _SETPGID: n1...2 -- r */
#ifndef _NO_VNPFORTH__SETPGID
extern void	_SETPGID (void);
#endif

/* _UMASK: n1     -- r */
#ifndef _NO_VNPFORTH__UMASK
extern void	_UMASK (void);
#endif

/* _CHROOT: n1     -- r */
#ifndef _NO_VNPFORTH__CHROOT
extern void	_CHROOT (void);
#endif

/* _DUP2: n1...2 -- r */
#ifndef _NO_VNPFORTH__DUP2
extern void	_DUP2 (void);
#endif

/* _GETPPID: -- r */
#ifndef _NO_VNPFORTH__GETPPID
extern void	_GETPPID (void);
#endif

/* _GETPGRP: -- r */
#ifndef _NO_VNPFORTH__GETPGRP
extern void	_GETPGRP (void);
#endif

/* _SETSID: -- r */
#ifndef _NO_VNPFORTH__SETSID
extern void	_SETSID (void);
#endif

/* _SETREUID16: n1...2 -- r */
#ifndef _NO_VNPFORTH__SETREUID16
extern void	_SETREUID16 (void);
#endif

/* _SETREGID16: n1...2 -- r */
#ifndef _NO_VNPFORTH__SETREGID16
extern void	_SETREGID16 (void);
#endif

/* _SYMLINK: n1...2 -- r */
#ifndef _NO_VNPFORTH__SYMLINK
extern void	_SYMLINK (void);
#endif

/* _READLINK: n1...3 -- r */
#ifndef _NO_VNPFORTH__READLINK
extern void	_READLINK (void);
#endif

/* _READDIR: n1     -- r */
#ifndef _NO_VNPFORTH__READDIR
extern void	_READDIR (void);
#endif

/* _MUNMAP: n1...2 -- r */
#ifndef _NO_VNPFORTH__MUNMAP
extern void	_MUNMAP (void);
#endif

/* _TRUNCATE: n1...2 -- r */
#ifndef _NO_VNPFORTH__TRUNCATE
extern void	_TRUNCATE (void);
#endif

/* _FTRUNCATE: n1...2 -- r */
#ifndef _NO_VNPFORTH__FTRUNCATE
extern void	_FTRUNCATE (void);
#endif

/* _FCHMOD: n1...2 -- r */
#ifndef _NO_VNPFORTH__FCHMOD
extern void	_FCHMOD (void);
#endif

/* _FCHOWN16: n1...3 -- r */
#ifndef _NO_VNPFORTH__FCHOWN16
extern void	_FCHOWN16 (void);
#endif

/* _GETPRIORITY: n1...2 -- r */
#ifndef _NO_VNPFORTH__GETPRIORITY
extern void	_GETPRIORITY (void);
#endif

/* _SETPRIORITY: n1...3 -- r */
#ifndef _NO_VNPFORTH__SETPRIORITY
extern void	_SETPRIORITY (void);
#endif

/* _SOCKETCALL: n1     -- r */
#ifndef _NO_VNPFORTH__SOCKETCALL
extern void	_SOCKETCALL (void);
#endif

/* _SYSLOG: n1...3 -- r */
#ifndef _NO_VNPFORTH__SYSLOG
extern void	_SYSLOG (void);
#endif

/* _SETITIMER: n1...3 -- r */
#ifndef _NO_VNPFORTH__SETITIMER
extern void	_SETITIMER (void);
#endif

/* _GETITIMER: n1...2 -- r */
#ifndef _NO_VNPFORTH__GETITIMER
extern void	_GETITIMER (void);
#endif

/* _STAT: n1...2 -- r */
#ifndef _NO_VNPFORTH__STAT
extern void	_STAT (void);
#endif

/* _LSTAT: n1...2 -- r */
#ifndef _NO_VNPFORTH__LSTAT
extern void	_LSTAT (void);
#endif

/* _FSTAT: n1...2 -- r */
#ifndef _NO_VNPFORTH__FSTAT
extern void	_FSTAT (void);
#endif

/* _UNAME: n1     -- r */
#ifndef _NO_VNPFORTH__UNAME
extern void	_UNAME (void);
#endif

/* _WAIT4: n1...4 -- r */
#ifndef _NO_VNPFORTH__WAIT4
extern void	_WAIT4 (void);
#endif

/* _SYSINFO: n1     -- r */
#ifndef _NO_VNPFORTH__SYSINFO
extern void	_SYSINFO (void);
#endif

/* _IPC: n1     -- r */
#ifndef _NO_VNPFORTH__IPC
extern void	_IPC (void);
#endif

/* _FSYNC: n1     -- r */
#ifndef _NO_VNPFORTH__FSYNC
extern void	_FSYNC (void);
#endif

/* _CLONE: n1...2 -- r */
#ifndef _NO_VNPFORTH__CLONE
extern void	_CLONE (void);
#endif

/* _NEW_UNAME: n1     -- r */
#ifndef _NO_VNPFORTH__NEW_UNAME
extern void	_NEW_UNAME (void);
#endif

/* _GETPGID: n1     -- r */
#ifndef _NO_VNPFORTH__GETPGID
extern void	_GETPGID (void);
#endif

/* _FCHDIR: n1     -- r */
#ifndef _NO_VNPFORTH__FCHDIR
extern void	_FCHDIR (void);
#endif

/* _PERSONALITY: n1     -- r */
#ifndef _NO_VNPFORTH__PERSONALITY
extern void	_PERSONALITY (void);
#endif

/* _SETFSUID: n1     -- r */
#ifndef _NO_VNPFORTH__SETFSUID
extern void	_SETFSUID (void);
#endif

/* _SETFSGID: n1     -- r */
#ifndef _NO_VNPFORTH__SETFSGID
extern void	_SETFSGID (void);
#endif

/* _LLSEEK: n1...5 -- r */
#ifndef _NO_VNPFORTH__LLSEEK
extern void	_LLSEEK (void);
#endif

/* _GETDENTS: n1...3 -- r */
#ifndef _NO_VNPFORTH__GETDENTS
extern void	_GETDENTS (void);
#endif

/* _SELECT: n1...5 -- r */
#ifndef _NO_VNPFORTH__SELECT
extern void	_SELECT (void);
#endif

/* _FLOCK: n1...2 -- r */
#ifndef _NO_VNPFORTH__FLOCK
extern void	_FLOCK (void);
#endif

/* _MSYNC: n1...3 -- r */
#ifndef _NO_VNPFORTH__MSYNC
extern void	_MSYNC (void);
#endif

/* _READV: n1...3 -- r */
#ifndef _NO_VNPFORTH__READV
extern void	_READV (void);
#endif

/* _WRITEV: n1...3 -- r */
#ifndef _NO_VNPFORTH__WRITEV
extern void	_WRITEV (void);
#endif

/* _NANOSLEEP: n1...2 -- r */
#ifndef _NO_VNPFORTH__NANOSLEEP
extern void	_NANOSLEEP (void);
#endif

/* _MREMAP: n1...4 -- r */
#ifndef _NO_VNPFORTH__MREMAP
extern void	_MREMAP (void);
#endif

/* _SETRESUID16: n1...3 -- r */
#ifndef _NO_VNPFORTH__SETRESUID16
extern void	_SETRESUID16 (void);
#endif

/* _GETRESUID16: n1...3 -- r */
#ifndef _NO_VNPFORTH__GETRESUID16
extern void	_GETRESUID16 (void);
#endif

/* _POLL: n1...3 -- r */
#ifndef _NO_VNPFORTH__POLL
extern void	_POLL (void);
#endif

/* _SETRESGID16: n1...3 -- r */
#ifndef _NO_VNPFORTH__SETRESGID16
extern void	_SETRESGID16 (void);
#endif

/* _GETRESGID16: n1...3 -- r */
#ifndef _NO_VNPFORTH__GETRESGID16
extern void	_GETRESGID16 (void);
#endif

/* _SIGRET: -- r */
#ifndef _NO_VNPFORTH__SIGRET
extern void	_SIGRET (void);
#endif

/* _SIGACTION: n1...3 -- r */
#ifndef _NO_VNPFORTH__SIGACTION
extern void	_SIGACTION (void);
#endif

/* _SIGPROCMASK: n1...4 -- r */
#ifndef _NO_VNPFORTH__SIGPROCMASK
extern void	_SIGPROCMASK (void);
#endif

/* _SIGPENDING: n1     -- r */
#ifndef _NO_VNPFORTH__SIGPENDING
extern void	_SIGPENDING (void);
#endif

/* _SIGTIMEDWAIT: n1...4 -- r */
#ifndef _NO_VNPFORTH__SIGTIMEDWAIT
extern void	_SIGTIMEDWAIT (void);
#endif

/* _SIGQUEUEINFO: n1...3 -- r */
#ifndef _NO_VNPFORTH__SIGQUEUEINFO
extern void	_SIGQUEUEINFO (void);
#endif

/* _SIGSUSPEND: n1...2 -- r */
#ifndef _NO_VNPFORTH__SIGSUSPEND
extern void	_SIGSUSPEND (void);
#endif

/* _PREAD: n1...4 -- r */
#ifndef _NO_VNPFORTH__PREAD
extern void	_PREAD (void);
#endif

/* _PWRITE: n1...4 -- r */
#ifndef _NO_VNPFORTH__PWRITE
extern void	_PWRITE (void);
#endif

/* _CHOWN16: n1...3 -- r */
#ifndef _NO_VNPFORTH__CHOWN16
extern void	_CHOWN16 (void);
#endif

/* _GETCWD: n1...2 -- r */
#ifndef _NO_VNPFORTH__GETCWD
extern void	_GETCWD (void);
#endif

/* _SIGALTSTACK: -- r */
#ifndef _NO_VNPFORTH__SIGALTSTACK
extern void	_SIGALTSTACK (void);
#endif

/* _SENDFILE: -- r */
#ifndef _NO_VNPFORTH__SENDFILE
extern void	_SENDFILE (void);
#endif

/* _VFORK: -- r */
#ifndef _NO_VNPFORTH__VFORK
extern void	_VFORK (void);
#endif

/* _GETRLIMIT: n1...2 -- r */
#ifndef _NO_VNPFORTH__GETRLIMIT
extern void	_GETRLIMIT (void);
#endif

/* _MMAP2: n1...6 -- r */
#ifndef _NO_VNPFORTH__MMAP2
extern void	_MMAP2 (void);
#endif

/* _LCHOWN: n1...3 -- r */
#ifndef _NO_VNPFORTH__LCHOWN
extern void	_LCHOWN (void);
#endif

/* _GETUID: -- r */
#ifndef _NO_VNPFORTH__GETUID
extern void	_GETUID (void);
#endif

/* _GETGID: -- r */
#ifndef _NO_VNPFORTH__GETGID
extern void	_GETGID (void);
#endif

/* _GETEUID: -- r */
#ifndef _NO_VNPFORTH__GETEUID
extern void	_GETEUID (void);
#endif

/* _GETEGID: -- r */
#ifndef _NO_VNPFORTH__GETEGID
extern void	_GETEGID (void);
#endif

/* _SETREUID: n1...2 -- r */
#ifndef _NO_VNPFORTH__SETREUID
extern void	_SETREUID (void);
#endif

/* _SETREGID: n1...2 -- r */
#ifndef _NO_VNPFORTH__SETREGID
extern void	_SETREGID (void);
#endif

/* _GETGROUPS: n1...2 -- r */
#ifndef _NO_VNPFORTH__GETGROUPS
extern void	_GETGROUPS (void);
#endif

/* _SETGROUPS: n1...2 -- r */
#ifndef _NO_VNPFORTH__SETGROUPS
extern void	_SETGROUPS (void);
#endif

/* _FCHOWN: n1...3 -- r */
#ifndef _NO_VNPFORTH__FCHOWN
extern void	_FCHOWN (void);
#endif

/* _SETRESUID: n1...3 -- r */
#ifndef _NO_VNPFORTH__SETRESUID
extern void	_SETRESUID (void);
#endif

/* _GETRESUID: n1...3 -- r */
#ifndef _NO_VNPFORTH__GETRESUID
extern void	_GETRESUID (void);
#endif

/* _SETRESGID: n1...3 -- r */
#ifndef _NO_VNPFORTH__SETRESGID
extern void	_SETRESGID (void);
#endif

/* _GETRESGID: n1...3 -- r */
#ifndef _NO_VNPFORTH__GETRESGID
extern void	_GETRESGID (void);
#endif

/* _CHOWN: n1...3 -- r */
#ifndef _NO_VNPFORTH__CHOWN
extern void	_CHOWN (void);
#endif

/* _SETUID: n1     -- r */
#ifndef _NO_VNPFORTH__SETUID
extern void	_SETUID (void);
#endif

/* _SETGID: n1     -- r */
#ifndef _NO_VNPFORTH__SETGID
extern void	_SETGID (void);
#endif

/* _PTRACE: n1...4 -- r */
#ifndef _NO_VNPFORTH__PTRACE
extern void	_PTRACE (void);
#endif

/* _SYNC: -- r */
#ifndef _NO_VNPFORTH__SYNC
extern void	_SYNC (void);
#endif

/* _ACCT: -- r */
#ifndef _NO_VNPFORTH__ACCT
extern void	_ACCT (void);
#endif

/* _UMOUNT: -- r */
#ifndef _NO_VNPFORTH__UMOUNT
extern void	_UMOUNT (void);
#endif

/* _USTAT: -- r */
#ifndef _NO_VNPFORTH__USTAT
extern void	_USTAT (void);
#endif

/* _SGETMASK: -- r */
#ifndef _NO_VNPFORTH__SGETMASK
extern void	_SGETMASK (void);
#endif

/* _SSETMASK: n1     -- r */
#ifndef _NO_VNPFORTH__SSETMASK
extern void	_SSETMASK (void);
#endif

/* _SETHOSTNAME: n1...2 -- r */
#ifndef _NO_VNPFORTH__SETHOSTNAME
extern void	_SETHOSTNAME (void);
#endif

/* _SETRLIMIT: n1...2 -- r */
#ifndef _NO_VNPFORTH__SETRLIMIT
extern void	_SETRLIMIT (void);
#endif

/* _GETRUSAGE: n1...2 -- r */
#ifndef _NO_VNPFORTH__GETRUSAGE
extern void	_GETRUSAGE (void);
#endif

/* _GETTIMEOFDAY: n1...2 -- r */
#ifndef _NO_VNPFORTH__GETTIMEOFDAY
extern void	_GETTIMEOFDAY (void);
#endif

/* _SETTIMEOFDAY: n1...2 -- r */
#ifndef _NO_VNPFORTH__SETTIMEOFDAY
extern void	_SETTIMEOFDAY (void);
#endif

/* _GETGROUPS16: n1...2 -- r */
#ifndef _NO_VNPFORTH__GETGROUPS16
extern void	_GETGROUPS16 (void);
#endif

/* _SETGROUPS16: n1...2 -- r */
#ifndef _NO_VNPFORTH__SETGROUPS16
extern void	_SETGROUPS16 (void);
#endif

/* _USELIB: n1     -- r */
#ifndef _NO_VNPFORTH__USELIB
extern void	_USELIB (void);
#endif

/* _SWAPON: n1     -- r */
#ifndef _NO_VNPFORTH__SWAPON
extern void	_SWAPON (void);
#endif

/* _REBOOT: n1...3 -- r */
#ifndef _NO_VNPFORTH__REBOOT
extern void	_REBOOT (void);
#endif

/* _STATFS: n1...2 -- r */
#ifndef _NO_VNPFORTH__STATFS
extern void	_STATFS (void);
#endif

/* _FSTATFS: n1...2 -- r */
#ifndef _NO_VNPFORTH__FSTATFS
extern void	_FSTATFS (void);
#endif

/* _IOPERM: n1...3 -- r */
#ifndef _NO_VNPFORTH__IOPERM
extern void	_IOPERM (void);
#endif

/* _IOPL: n1     -- r */
#ifndef _NO_VNPFORTH__IOPL
extern void	_IOPL (void);
#endif

/* _VHANGUP: -- r */
#ifndef _NO_VNPFORTH__VHANGUP
extern void	_VHANGUP (void);
#endif

/* _SWAPOFF: n1     -- r */
#ifndef _NO_VNPFORTH__SWAPOFF
extern void	_SWAPOFF (void);
#endif

/* _SETDOMAINNAME: n1     -- r */
#ifndef _NO_VNPFORTH__SETDOMAINNAME
extern void	_SETDOMAINNAME (void);
#endif

/* _MODIFY_LDT: -- r */
#ifndef _NO_VNPFORTH__MODIFY_LDT
extern void	_MODIFY_LDT (void);
#endif

/* _ADJTIMEX: -- r */
#ifndef _NO_VNPFORTH__ADJTIMEX
extern void	_ADJTIMEX (void);
#endif

/* _MPROTECT: n1...3 -- r */
#ifndef _NO_VNPFORTH__MPROTECT
extern void	_MPROTECT (void);
#endif

/* _CREATE_MODULE: -- r */
#ifndef _NO_VNPFORTH__CREATE_MODULE
extern void	_CREATE_MODULE (void);
#endif

/* _INIT_MODULE: -- r */
#ifndef _NO_VNPFORTH__INIT_MODULE
extern void	_INIT_MODULE (void);
#endif

/* _DELETE_MODULE: -- r */
#ifndef _NO_VNPFORTH__DELETE_MODULE
extern void	_DELETE_MODULE (void);
#endif

/* _GET_KERNEL_SYMS: -- r */
#ifndef _NO_VNPFORTH__GET_KERNEL_SYMS
extern void	_GET_KERNEL_SYMS (void);
#endif

/* _QUOTACTL: n1...4 -- r */
#ifndef _NO_VNPFORTH__QUOTACTL
extern void	_QUOTACTL (void);
#endif

/* _BDFLUSH: -- r */
#ifndef _NO_VNPFORTH__BDFLUSH
extern void	_BDFLUSH (void);
#endif

/* _SYSFS: n1     -- r */
#ifndef _NO_VNPFORTH__SYSFS
extern void	_SYSFS (void);
#endif

/* _GETSID: n1     -- r */
#ifndef _NO_VNPFORTH__GETSID
extern void	_GETSID (void);
#endif

/* _FDATASYNC: n1     -- r */
#ifndef _NO_VNPFORTH__FDATASYNC
extern void	_FDATASYNC (void);
#endif

/* _SYSCTL: n1     -- r */
#ifndef _NO_VNPFORTH__SYSCTL
extern void	_SYSCTL (void);
#endif

/* _MLOCK: n1...2 -- r */
#ifndef _NO_VNPFORTH__MLOCK
extern void	_MLOCK (void);
#endif

/* _MUNLOCK: n1...2 -- r */
#ifndef _NO_VNPFORTH__MUNLOCK
extern void	_MUNLOCK (void);
#endif

/* _MLOCKALL: n1     -- r */
#ifndef _NO_VNPFORTH__MLOCKALL
extern void	_MLOCKALL (void);
#endif

/* _MUNLOCKALL: -- r */
#ifndef _NO_VNPFORTH__MUNLOCKALL
extern void	_MUNLOCKALL (void);
#endif

/* _SCHED_SETPARAM: n1...2 -- r */
#ifndef _NO_VNPFORTH__SCHED_SETPARAM
extern void	_SCHED_SETPARAM (void);
#endif

/* _SCHED_GETPARAM: n1...2 -- r */
#ifndef _NO_VNPFORTH__SCHED_GETPARAM
extern void	_SCHED_GETPARAM (void);
#endif

/* _SCHED_SETSCHEDULER: n1...3 -- r */
#ifndef _NO_VNPFORTH__SCHED_SETSCHEDULER
extern void	_SCHED_SETSCHEDULER (void);
#endif

/* _SCHED_GETSCHEDULER: n1     -- r */
#ifndef _NO_VNPFORTH__SCHED_GETSCHEDULER
extern void	_SCHED_GETSCHEDULER (void);
#endif

/* _SCHED_YIELD: -- r */
#ifndef _NO_VNPFORTH__SCHED_YIELD
extern void	_SCHED_YIELD (void);
#endif

/* _SCHED_GET_PRIORITY_MAX: n1     -- r */
#ifndef _NO_VNPFORTH__SCHED_GET_PRIORITY_MAX
extern void	_SCHED_GET_PRIORITY_MAX (void);
#endif

/* _SCHED_GET_PRIORITY_MIN: n1     -- r */
#ifndef _NO_VNPFORTH__SCHED_GET_PRIORITY_MIN
extern void	_SCHED_GET_PRIORITY_MIN (void);
#endif

/* _SCHED_RR_GET_INTERVAL: n1...2 -- r */
#ifndef _NO_VNPFORTH__SCHED_RR_GET_INTERVAL
extern void	_SCHED_RR_GET_INTERVAL (void);
#endif

/* _VM86: n1...2 -- r */
#ifndef _NO_VNPFORTH__VM86
extern void	_VM86 (void);
#endif

/* _QUERY_MODULE: n1...5 -- r */
#ifndef _NO_VNPFORTH__QUERY_MODULE
extern void	_QUERY_MODULE (void);
#endif

/* _NFSSERVCTL: n1...3 -- r */
#ifndef _NO_VNPFORTH__NFSSERVCTL
extern void	_NFSSERVCTL (void);
#endif

/* _PRCTL: n1...5 -- r */
#ifndef _NO_VNPFORTH__PRCTL
extern void	_PRCTL (void);
#endif

/* _CAPGET: n1...2 -- r */
#ifndef _NO_VNPFORTH__CAPGET
extern void	_CAPGET (void);
#endif

/* _CAPSET: n1...2 -- r */
#ifndef _NO_VNPFORTH__CAPSET
extern void	_CAPSET (void);
#endif

/* _TRUNCATE64: n1...3 -- r */
#ifndef _NO_VNPFORTH__TRUNCATE64
extern void	_TRUNCATE64 (void);
#endif

/* _FTRUNCATE64: n1...3 -- r */
#ifndef _NO_VNPFORTH__FTRUNCATE64
extern void	_FTRUNCATE64 (void);
#endif

/* _STAT64: n1...2 -- r */
#ifndef _NO_VNPFORTH__STAT64
extern void	_STAT64 (void);
#endif

/* _LSTAT64: n1...2 -- r */
#ifndef _NO_VNPFORTH__LSTAT64
extern void	_LSTAT64 (void);
#endif

/* _FSTAT64: n1...2 -- r */
#ifndef _NO_VNPFORTH__FSTAT64
extern void	_FSTAT64 (void);
#endif

/* _PIVOT_ROOT: n1...2 -- r */
#ifndef _NO_VNPFORTH__PIVOT_ROOT
extern void	_PIVOT_ROOT (void);
#endif

/* _MINCORE: n1...3 -- r */
#ifndef _NO_VNPFORTH__MINCORE
extern void	_MINCORE (void);
#endif

/* _MADVISE: n1...3 -- r */
#ifndef _NO_VNPFORTH__MADVISE
extern void	_MADVISE (void);
#endif

/* _EPERM: (--   1) Operation not permitted */
#ifndef _NO_VNPFORTH__EPERM
extern void	_EPERM (void);
#endif

/* _ENOENT: (--   2) No such file or directory */
#ifndef _NO_VNPFORTH__ENOENT
extern void	_ENOENT (void);
#endif

/* _ESRCH: (--   3) No such process */
#ifndef _NO_VNPFORTH__ESRCH
extern void	_ESRCH (void);
#endif

/* _EINTR: (--   4) Interrupted system call */
#ifndef _NO_VNPFORTH__EINTR
extern void	_EINTR (void);
#endif

/* _EIO: (--   5) I/O error */
#ifndef _NO_VNPFORTH__EIO
extern void	_EIO (void);
#endif

/* _ENXIO: (--   6) No such device or address */
#ifndef _NO_VNPFORTH__ENXIO
extern void	_ENXIO (void);
#endif

/* _E2BIG: (--   7) Arg list too long */
#ifndef _NO_VNPFORTH__E2BIG
extern void	_E2BIG (void);
#endif

/* _ENOEXEC: (--   8) Exec format error */
#ifndef _NO_VNPFORTH__ENOEXEC
extern void	_ENOEXEC (void);
#endif

/* _EBADF: (--   9) Bad file number */
#ifndef _NO_VNPFORTH__EBADF
extern void	_EBADF (void);
#endif

/* _ECHILD: (--  10) No child processes */
#ifndef _NO_VNPFORTH__ECHILD
extern void	_ECHILD (void);
#endif

/* _EAGAIN: (--  11) Try again */
#ifndef _NO_VNPFORTH__EAGAIN
extern void	_EAGAIN (void);
#endif

/* _ENOMEM: (--  12) Out of memory */
#ifndef _NO_VNPFORTH__ENOMEM
extern void	_ENOMEM (void);
#endif

/* _EACCES: (--  13) Permission denied */
#ifndef _NO_VNPFORTH__EACCES
extern void	_EACCES (void);
#endif

/* _EFAULT: (--  14) Bad address */
#ifndef _NO_VNPFORTH__EFAULT
extern void	_EFAULT (void);
#endif

/* _ENOTBLK: (--  15) Block device required */
#ifndef _NO_VNPFORTH__ENOTBLK
extern void	_ENOTBLK (void);
#endif

/* _EBUSY: (--  16) Device or resource busy */
#ifndef _NO_VNPFORTH__EBUSY
extern void	_EBUSY (void);
#endif

/* _EEXIST: (--  17) File exists */
#ifndef _NO_VNPFORTH__EEXIST
extern void	_EEXIST (void);
#endif

/* _EXDEV: (--  18) Cross-device link */
#ifndef _NO_VNPFORTH__EXDEV
extern void	_EXDEV (void);
#endif

/* _ENODEV: (--  19) No such device */
#ifndef _NO_VNPFORTH__ENODEV
extern void	_ENODEV (void);
#endif

/* _ENOTDIR: (--  20) Not a directory */
#ifndef _NO_VNPFORTH__ENOTDIR
extern void	_ENOTDIR (void);
#endif

/* _EISDIR: (--  21) Is a directory */
#ifndef _NO_VNPFORTH__EISDIR
extern void	_EISDIR (void);
#endif

/* _EINVAL: (--  22) Invalid argument */
#ifndef _NO_VNPFORTH__EINVAL
extern void	_EINVAL (void);
#endif

/* _ENFILE: (--  23) File table overflow */
#ifndef _NO_VNPFORTH__ENFILE
extern void	_ENFILE (void);
#endif

/* _EMFILE: (--  24) Too many open files */
#ifndef _NO_VNPFORTH__EMFILE
extern void	_EMFILE (void);
#endif

/* _ENOTTY: (--  25) Not a typewriter */
#ifndef _NO_VNPFORTH__ENOTTY
extern void	_ENOTTY (void);
#endif

/* _ETXTBSY: (--  26) Text file busy */
#ifndef _NO_VNPFORTH__ETXTBSY
extern void	_ETXTBSY (void);
#endif

/* _EFBIG: (--  27) File too large */
#ifndef _NO_VNPFORTH__EFBIG
extern void	_EFBIG (void);
#endif

/* _ENOSPC: (--  28) No space left on device */
#ifndef _NO_VNPFORTH__ENOSPC
extern void	_ENOSPC (void);
#endif

/* _ESPIPE: (--  29) Illegal seek */
#ifndef _NO_VNPFORTH__ESPIPE
extern void	_ESPIPE (void);
#endif

/* _EROFS: (--  30) Read-only file system */
#ifndef _NO_VNPFORTH__EROFS
extern void	_EROFS (void);
#endif

/* _EMLINK: (--  31) Too many links */
#ifndef _NO_VNPFORTH__EMLINK
extern void	_EMLINK (void);
#endif

/* _EPIPE: (--  32) Broken pipe */
#ifndef _NO_VNPFORTH__EPIPE
extern void	_EPIPE (void);
#endif

/* _EDOM: (--  33) Math argument out of domain of func */
#ifndef _NO_VNPFORTH__EDOM
extern void	_EDOM (void);
#endif

/* _ERANGE: (--  34) Math result not representable */
#ifndef _NO_VNPFORTH__ERANGE
extern void	_ERANGE (void);
#endif

/* _EDEADLK: (--  35) Resource deadlock would occur */
#ifndef _NO_VNPFORTH__EDEADLK
extern void	_EDEADLK (void);
#endif

/* _ENAMETOOLONG: (--  36) File name too long */
#ifndef _NO_VNPFORTH__ENAMETOOLONG
extern void	_ENAMETOOLONG (void);
#endif

/* _ENOLCK: (--  37) No record locks available */
#ifndef _NO_VNPFORTH__ENOLCK
extern void	_ENOLCK (void);
#endif

/* _ENOSYS: (--  38) Function not implemented */
#ifndef _NO_VNPFORTH__ENOSYS
extern void	_ENOSYS (void);
#endif

/* _ENOTEMPTY: (--  39) Directory not empty */
#ifndef _NO_VNPFORTH__ENOTEMPTY
extern void	_ENOTEMPTY (void);
#endif

/* _ELOOP: (--  40) Too many symbolic links encountered */
#ifndef _NO_VNPFORTH__ELOOP
extern void	_ELOOP (void);
#endif

/* _EWOULDBLOCK: (-- _EAGAIN) Operation would block */
#ifndef _NO_VNPFORTH__EWOULDBLOCK
extern void	_EWOULDBLOCK (void);
#endif

/* _ENOMSG: (--  42) No message of desired type */
#ifndef _NO_VNPFORTH__ENOMSG
extern void	_ENOMSG (void);
#endif

/* _EIDRM: (--  43) Identifier removed */
#ifndef _NO_VNPFORTH__EIDRM
extern void	_EIDRM (void);
#endif

/* _ECHRNG: (--  44) Channel number out of range */
#ifndef _NO_VNPFORTH__ECHRNG
extern void	_ECHRNG (void);
#endif

/* _EL2NSYNC: (--  45) Level 2 not synchronized */
#ifndef _NO_VNPFORTH__EL2NSYNC
extern void	_EL2NSYNC (void);
#endif

/* _EL3HLT: (--  46) Level 3 halted */
#ifndef _NO_VNPFORTH__EL3HLT
extern void	_EL3HLT (void);
#endif

/* _EL3RST: (--  47) Level 3 reset */
#ifndef _NO_VNPFORTH__EL3RST
extern void	_EL3RST (void);
#endif

/* _ELNRNG: (--  48) Link number out of range */
#ifndef _NO_VNPFORTH__ELNRNG
extern void	_ELNRNG (void);
#endif

/* _EUNATCH: (--  49) Protocol driver not attached */
#ifndef _NO_VNPFORTH__EUNATCH
extern void	_EUNATCH (void);
#endif

/* _ENOCSI: (--  50) No CSI structure available */
#ifndef _NO_VNPFORTH__ENOCSI
extern void	_ENOCSI (void);
#endif

/* _EL2HLT: (--  51) Level 2 halted */
#ifndef _NO_VNPFORTH__EL2HLT
extern void	_EL2HLT (void);
#endif

/* _EBADE: (--  52) Invalid exchange */
#ifndef _NO_VNPFORTH__EBADE
extern void	_EBADE (void);
#endif

/* _EBADR: (--  53) Invalid request descriptor */
#ifndef _NO_VNPFORTH__EBADR
extern void	_EBADR (void);
#endif

/* _EXFULL: (--  54) Exchange full */
#ifndef _NO_VNPFORTH__EXFULL
extern void	_EXFULL (void);
#endif

/* _ENOANO: (--  55) No anode */
#ifndef _NO_VNPFORTH__ENOANO
extern void	_ENOANO (void);
#endif

/* _EBADRQC: (--  56) Invalid request code */
#ifndef _NO_VNPFORTH__EBADRQC
extern void	_EBADRQC (void);
#endif

/* _EBADSLT: (--  57) Invalid slot */
#ifndef _NO_VNPFORTH__EBADSLT
extern void	_EBADSLT (void);
#endif

/* _EDEADLOCK: (-- _EDEADLK) Resource deadlck would occur */
#ifndef _NO_VNPFORTH__EDEADLOCK
extern void	_EDEADLOCK (void);
#endif

/* _EBFONT: (--  59) Bad font file format */
#ifndef _NO_VNPFORTH__EBFONT
extern void	_EBFONT (void);
#endif

/* _ENOSTR: (--  60) Device not a stream */
#ifndef _NO_VNPFORTH__ENOSTR
extern void	_ENOSTR (void);
#endif

/* _ENODATA: (--  61) No data available */
#ifndef _NO_VNPFORTH__ENODATA
extern void	_ENODATA (void);
#endif

/* _ETIME: (--  62) Timer expired */
#ifndef _NO_VNPFORTH__ETIME
extern void	_ETIME (void);
#endif

/* _ENOSR: (--  63) Out of streams resources */
#ifndef _NO_VNPFORTH__ENOSR
extern void	_ENOSR (void);
#endif

/* _ENONET: (--  64) Machine is not on the network */
#ifndef _NO_VNPFORTH__ENONET
extern void	_ENONET (void);
#endif

/* _ENOPKG: (--  65) Package not installed */
#ifndef _NO_VNPFORTH__ENOPKG
extern void	_ENOPKG (void);
#endif

/* _EREMOTE: (--  66) Object is remote */
#ifndef _NO_VNPFORTH__EREMOTE
extern void	_EREMOTE (void);
#endif

/* _ENOLINK: (--  67) Link has been severed */
#ifndef _NO_VNPFORTH__ENOLINK
extern void	_ENOLINK (void);
#endif

/* _EADV: (--  68) Advertise error */
#ifndef _NO_VNPFORTH__EADV
extern void	_EADV (void);
#endif

/* _ESRMNT: (--  69) Srmount error */
#ifndef _NO_VNPFORTH__ESRMNT
extern void	_ESRMNT (void);
#endif

/* _ECOMM: (--  70) Communication error on send */
#ifndef _NO_VNPFORTH__ECOMM
extern void	_ECOMM (void);
#endif

/* _EPROTO: (--  71) Protocol error */
#ifndef _NO_VNPFORTH__EPROTO
extern void	_EPROTO (void);
#endif

/* _EMULTIHOP: (--  72) Multihop attempted */
#ifndef _NO_VNPFORTH__EMULTIHOP
extern void	_EMULTIHOP (void);
#endif

/* _EDOTDOT: (--  73) RFS specific error */
#ifndef _NO_VNPFORTH__EDOTDOT
extern void	_EDOTDOT (void);
#endif

/* _EBADMSG: (--  74) Not a data message */
#ifndef _NO_VNPFORTH__EBADMSG
extern void	_EBADMSG (void);
#endif

/* _EOVERFLOW: (--  75) Value too large for defined data type */
#ifndef _NO_VNPFORTH__EOVERFLOW
extern void	_EOVERFLOW (void);
#endif

/* _ENOTUNIQ: (--  76) Name not unique on network */
#ifndef _NO_VNPFORTH__ENOTUNIQ
extern void	_ENOTUNIQ (void);
#endif

/* _EBADFD: (--  77) File descriptor in bad state */
#ifndef _NO_VNPFORTH__EBADFD
extern void	_EBADFD (void);
#endif

/* _EREMCHG: (--  78) Remote address changed */
#ifndef _NO_VNPFORTH__EREMCHG
extern void	_EREMCHG (void);
#endif

/* _ELIBACC: (--  79) Can not access a needed shared library */
#ifndef _NO_VNPFORTH__ELIBACC
extern void	_ELIBACC (void);
#endif

/* _ELIBBAD: (--  80) Accessing a corrupted shared library */
#ifndef _NO_VNPFORTH__ELIBBAD
extern void	_ELIBBAD (void);
#endif

/* _ELIBSCN: (--  81) .lib section in a.out corrupted */
#ifndef _NO_VNPFORTH__ELIBSCN
extern void	_ELIBSCN (void);
#endif

/* _ELIBMAX: (--  82) Attempting to link in too many shared libs */
#ifndef _NO_VNPFORTH__ELIBMAX
extern void	_ELIBMAX (void);
#endif

/* _ELIBEXEC: (--  83) Cannot exec a shared library directly */
#ifndef _NO_VNPFORTH__ELIBEXEC
extern void	_ELIBEXEC (void);
#endif

/* _EILSEQ: (--  84) Illegal byte sequence */
#ifndef _NO_VNPFORTH__EILSEQ
extern void	_EILSEQ (void);
#endif

/* _ERESTART: (--  85) Interrupted sys call should be restarted */
#ifndef _NO_VNPFORTH__ERESTART
extern void	_ERESTART (void);
#endif

/* _ESTRPIPE: (--  86) Streams pipe error */
#ifndef _NO_VNPFORTH__ESTRPIPE
extern void	_ESTRPIPE (void);
#endif

/* _EUSERS: (--  87) Too many users */
#ifndef _NO_VNPFORTH__EUSERS
extern void	_EUSERS (void);
#endif

/* _ENOTSOCK: (--  88) Socket operation on non-socket */
#ifndef _NO_VNPFORTH__ENOTSOCK
extern void	_ENOTSOCK (void);
#endif

/* _EDESTADDRREQ: (--  89) Destination address required */
#ifndef _NO_VNPFORTH__EDESTADDRREQ
extern void	_EDESTADDRREQ (void);
#endif

/* _EMSGSIZE: (--  90) Message too long */
#ifndef _NO_VNPFORTH__EMSGSIZE
extern void	_EMSGSIZE (void);
#endif

/* _EPROTOTYPE: (--  91) Protocol wrong type for socket */
#ifndef _NO_VNPFORTH__EPROTOTYPE
extern void	_EPROTOTYPE (void);
#endif

/* _ENOPROTOOPT: (--  92) Protocol not available */
#ifndef _NO_VNPFORTH__ENOPROTOOPT
extern void	_ENOPROTOOPT (void);
#endif

/* _EPROTONOSUPPORT: (--  93) Protocol not supported */
#ifndef _NO_VNPFORTH__EPROTONOSUPPORT
extern void	_EPROTONOSUPPORT (void);
#endif

/* _ESOCKTNOSUPPORT: (--  94) Socket type not supported */
#ifndef _NO_VNPFORTH__ESOCKTNOSUPPORT
extern void	_ESOCKTNOSUPPORT (void);
#endif

/* _EOPNOTSUPP: (--  95) Operation not supported on transport endpt */
#ifndef _NO_VNPFORTH__EOPNOTSUPP
extern void	_EOPNOTSUPP (void);
#endif

/* _EPFNOSUPPORT: (--  96) Protocol family not supported */
#ifndef _NO_VNPFORTH__EPFNOSUPPORT
extern void	_EPFNOSUPPORT (void);
#endif

/* _EAFNOSUPPORT: (--  97) Address family not supported by protocol */
#ifndef _NO_VNPFORTH__EAFNOSUPPORT
extern void	_EAFNOSUPPORT (void);
#endif

/* _EADDRINUSE: (--  98) Address already in use */
#ifndef _NO_VNPFORTH__EADDRINUSE
extern void	_EADDRINUSE (void);
#endif

/* _EADDRNOTAVAIL: (--  99) Cannot assign requested address */
#ifndef _NO_VNPFORTH__EADDRNOTAVAIL
extern void	_EADDRNOTAVAIL (void);
#endif

/* _ENETDOWN: (-- 100) Network is down */
#ifndef _NO_VNPFORTH__ENETDOWN
extern void	_ENETDOWN (void);
#endif

/* _ENETUNREACH: (-- 101) Network is unreachable */
#ifndef _NO_VNPFORTH__ENETUNREACH
extern void	_ENETUNREACH (void);
#endif

/* _ENETRESET: (-- 102) Netwrk dropped connection because of reset */
#ifndef _NO_VNPFORTH__ENETRESET
extern void	_ENETRESET (void);
#endif

/* _ECONNABORTED: (-- 103) Software caused connection abort */
#ifndef _NO_VNPFORTH__ECONNABORTED
extern void	_ECONNABORTED (void);
#endif

/* _ECONNRESET: (-- 104) Connection reset by peer */
#ifndef _NO_VNPFORTH__ECONNRESET
extern void	_ECONNRESET (void);
#endif

/* _ENOBUFS: (-- 105) No buffer space available */
#ifndef _NO_VNPFORTH__ENOBUFS
extern void	_ENOBUFS (void);
#endif

/* _EISCONN: (-- 106) Transport endpoint is already connected */
#ifndef _NO_VNPFORTH__EISCONN
extern void	_EISCONN (void);
#endif

/* _ENOTCONN: (-- 107) Transport endpoint is not connected */
#ifndef _NO_VNPFORTH__ENOTCONN
extern void	_ENOTCONN (void);
#endif

/* _ESHUTDOWN: (-- 108) Cannot send after transport endpoint shtdn */
#ifndef _NO_VNPFORTH__ESHUTDOWN
extern void	_ESHUTDOWN (void);
#endif

/* _ETOOMANYREFS: (-- 109) Too many references: cannot splice */
#ifndef _NO_VNPFORTH__ETOOMANYREFS
extern void	_ETOOMANYREFS (void);
#endif

/* _ETIMEDOUT: (-- 110) Connection timed out */
#ifndef _NO_VNPFORTH__ETIMEDOUT
extern void	_ETIMEDOUT (void);
#endif

/* _ECONNREFUSED: (-- 111) Connection refused */
#ifndef _NO_VNPFORTH__ECONNREFUSED
extern void	_ECONNREFUSED (void);
#endif

/* _EHOSTDOWN: (-- 112) Host is down */
#ifndef _NO_VNPFORTH__EHOSTDOWN
extern void	_EHOSTDOWN (void);
#endif

/* _EHOSTUNREACH: (-- 113) No route to host */
#ifndef _NO_VNPFORTH__EHOSTUNREACH
extern void	_EHOSTUNREACH (void);
#endif

/* _EALREADY: (-- 114) Operation already in progress */
#ifndef _NO_VNPFORTH__EALREADY
extern void	_EALREADY (void);
#endif

/* _EINPROGRESS: (-- 115) Operation now in progress */
#ifndef _NO_VNPFORTH__EINPROGRESS
extern void	_EINPROGRESS (void);
#endif

/* _ESTALE: (-- 116) Stale NFS file handle */
#ifndef _NO_VNPFORTH__ESTALE
extern void	_ESTALE (void);
#endif

/* _EUCLEAN: (-- 117) Structure needs cleaning */
#ifndef _NO_VNPFORTH__EUCLEAN
extern void	_EUCLEAN (void);
#endif

/* _ENOTNAM: (-- 118) Not a XENIX named type file */
#ifndef _NO_VNPFORTH__ENOTNAM
extern void	_ENOTNAM (void);
#endif

/* _ENAVAIL: (-- 119) No XENIX semaphores available */
#ifndef _NO_VNPFORTH__ENAVAIL
extern void	_ENAVAIL (void);
#endif

/* _EISNAM: (-- 120) Is a named type file */
#ifndef _NO_VNPFORTH__EISNAM
extern void	_EISNAM (void);
#endif

/* _EREMOTEIO: (-- 121) Remote I/O error */
#ifndef _NO_VNPFORTH__EREMOTEIO
extern void	_EREMOTEIO (void);
#endif

/* _EDQUOT: (-- 122) Quota exceeded */
#ifndef _NO_VNPFORTH__EDQUOT
extern void	_EDQUOT (void);
#endif

/* _ENOMEDIUM: (-- 123) No medium found */
#ifndef _NO_VNPFORTH__ENOMEDIUM
extern void	_ENOMEDIUM (void);
#endif

/* _EMEDIUMTYPE: (-- 124) Wrong medium type */
#ifndef _NO_VNPFORTH__EMEDIUMTYPE
extern void	_EMEDIUMTYPE (void);
#endif


#if defined(__cplusplus)
}
#endif /* __cplusplus */
#endif /* _FORTHLIB_H */
